Module telnet

Module telnet 

Telnet command interface for receiving measurement requests

The RIPE Atlas controller sends measurement specifications over the reverse-tunneled telnet connection. This module handles parsing and dispatching these commands.

Structs

DnsSpec
DNS measurement specification
HostTelemetrySpec
Host-telemetry scheduling spec parsed from a CRONLINE.
HttpSpec
HTTP measurement specification
NtpSpec
NTP measurement specification
PingSpec
Ping measurement specification
ScheduleSpec
Common scheduling fields for recurring measurements
TelnetServer
Telnet server for receiving controller commands
TlsSpec
TLS/SSL measurement specification
TracerouteSpec
Traceroute measurement specification

Enums

HostTelemetryKind
Which host-telemetry reporter the controller is asking us to run.
TelnetCommand
Telnet command received from controller

Functions

handle_connection
Handle a single telnet connection with Atlas authentication.
parse_command
Parse a command line into a TelnetCommand