pub struct KnownHosts { /* private fields */ }Expand description
Known SSH host keys for server verification (TOFU model)
On first connection to a server, the key is saved to a known_hosts file. On subsequent connections, the presented key is verified against the saved one. This prevents MITM attacks after the initial connection.
Implementations